@@ -3,7 +3,7 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-# pylint: disable=invalid-overridden-method
+
 import functools
 from typing import (  # pylint: disable=unused-import
     Union, Optional, Any, Iterable, Dict, List,
@@ -21,16 +21,17 @@ from .._shared.base_client_async import AsyncStorageAccountHostsMixin, AsyncTran
 from .._shared.response_handlers import return_response_headers, process_storage_error
 from .._shared.parser import _to_utc_datetime
 from .._shared.response_handlers import parse_to_internal_user_delegation_key
-from .._generated import VERSION
 from .._generated.aio import AzureBlobStorage
 from .._generated.models import StorageErrorException, StorageServiceProperties, KeyInfo
 from .._blob_service_client import BlobServiceClient as BlobServiceClientBase
 from ._container_client_async import ContainerClient
 from ._blob_client_async import BlobClient
-from .._models import ContainerProperties
-from .._deserialize import service_stats_deserialize, service_properties_deserialize
-from .._serialize import get_api_version
-from ._models import ContainerPropertiesPaged, FilteredBlobPaged
+from .._models import (
+    ContainerProperties,
+    service_stats_deserialize,
+    service_properties_deserialize,
+)
+from ._models import ContainerPropertiesPaged
 
 if TYPE_CHECKING:
     from datetime import datetime
@@ -66,17 +67,11 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         account URL already has a SAS token. The value can be a SAS token string, an account
         shared access key, or an instance of a TokenCredentials class from azure.identity.
         If the URL already has a SAS token, specifying an explicit credential will take priority.
-    :keyword str api_version:
-        The Storage API version to use for requests. Default value is '2019-07-07'.
-        Setting to an older version may result in reduced feature compatibility.
-
-        .. versionadded:: 12.2.0
-
     :keyword str secondary_hostname:
         The hostname of the secondary endpoint.
     :keyword int max_block_size: The maximum chunk size for uploading a block blob in chunks.
         Defaults to 4*1024*1024, or 4MB.
-    :keyword int max_single_put_size: If the blob size is less than or equal max_single_put_size, then the blob will be
+    :keyword int max_single_put_size: If the blob size is less than max_single_put_size, then the blob will be
         uploaded with only one http PUT request. If the blob size is larger than max_single_put_size,
         the blob will be uploaded in chunks. Defaults to 64*1024*1024, or 64MB.
     :keyword int min_large_block_upload_threshold: The minimum chunk size required to use the memory efficient
@@ -117,7 +112,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             credential=credential,
             **kwargs)
         self._client = AzureBlobStorage(url=self.url, pipeline=self._pipeline)
-        self._client._config.version = get_api_version(kwargs, VERSION)  # pylint: disable=protected-access
         self._loop = kwargs.get('loop', None)
 
     @distributed_trace_async
@@ -337,10 +331,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         :param bool include_metadata:
             Specifies that container metadata to be returned in the response.
             The default value is `False`.
-        :keyword bool include_deleted:
-            Specifies that deleted containers to be returned in the response. This is for container restore enabled
-            account. The default value is `False`.
-            .. versionadded:: 12.4.0
         :keyword int results_per_page:
             The maximum number of container names to retrieve per API
             call. If the request does not specify the server will return up to 5,000 items.
@@ -358,10 +348,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
                 :dedent: 16
                 :caption: Listing the containers in the blob service.
         """
-        include = ['metadata'] if include_metadata else []
-        include_deleted = kwargs.pop('include_deleted', None)
-        if include_deleted:
-            include.append("deleted")
+        include = 'metadata' if include_metadata else None
         timeout = kwargs.pop('timeout', None)
         results_per_page = kwargs.pop('results_per_page', None)
         command = functools.partial(
@@ -377,37 +364,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             page_iterator_class=ContainerPropertiesPaged
         )
 
-    @distributed_trace
-    def find_blobs_by_tags(self, filter_expression, **kwargs):
-        # type: (str, **Any) -> AsyncItemPaged[FilteredBlob]
-        """The Filter Blobs operation enables callers to list blobs across all
-        containers whose tags match a given search expression.  Filter blobs
-        searches across all containers within a storage account but can be
-        scoped within the expression to a single container.
-
-        :param str filter_expression:
-            The expression to find blobs whose tags matches the specified condition.
-            eg. "\"yourtagname\"='firsttag' and \"yourtagname2\"='secondtag'"
-            To specify a container, eg. "@container='containerName' and \"Name\"='C'"
-        :keyword int results_per_page:
-            The max result per page when paginating.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :returns: An iterable (auto-paging) response of BlobProperties.
-        :rtype: ~azure.core.async_paging.AsyncItemPaged[~azure.storage.blob.FilteredBlob]
-        """
-
-        results_per_page = kwargs.pop('results_per_page', None)
-        timeout = kwargs.pop('timeout', None)
-        command = functools.partial(
-            self._client.service.filter_blobs,
-            where=filter_expression,
-            timeout=timeout,
-            **kwargs)
-        return AsyncItemPaged(
-            command, results_per_page=results_per_page,
-            page_iterator_class=FilteredBlobPaged)
-
     @distributed_trace_async
     async def create_container(
             self, name,  # type: str
@@ -430,13 +386,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         :param public_access:
             Possible values include: 'container', 'blob'.
         :type public_access: str or ~azure.storage.blob.PublicAccess
-        :keyword container_encryption_scope:
-            Specifies the default encryption scope to set on the container and use for
-            all future writes.
-
-            .. versionadded:: 12.2.0
-
-        :paramtype container_encryption_scope: dict or ~azure.storage.blob.ContainerEncryptionScope
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :rtype: ~azure.storage.blob.aio.ContainerClient
@@ -516,38 +465,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             timeout=timeout,
             **kwargs)
 
-    @distributed_trace_async
-    async def undelete_container(self, deleted_container_name, deleted_container_version, **kwargs):
-        # type: (str, str, str, **Any) -> ContainerClient
-        """Restores soft-deleted container.
-
-        Operation will only be successful if used within the specified number of days
-        set in the delete retention policy.
-
-        .. versionadded:: 12.4.0
-            This operation was introduced in API version '2019-12-12'.
-
-        :param str deleted_container_name:
-            Specifies the name of the deleted container to restore.
-        :param str deleted_container_version:
-            Specifies the version of the deleted container to restore.
-        :keyword str new_name:
-            The new name for the deleted container to be restored to.
-            If not specified deleted_container_name will be used as the restored container name.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :rtype: ~azure.storage.blob.aio.ContainerClient
-        """
-        new_name = kwargs.pop('new_name', None)
-        container = self.get_container_client(new_name or deleted_container_name)
-        try:
-            await container._client.container.restore(deleted_container_name=deleted_container_name, # pylint: disable = protected-access
-                                                      deleted_container_version=deleted_container_version,
-                                                      timeout=kwargs.pop('timeout', None), **kwargs)
-            return container
-        except StorageErrorException as error:
-            process_storage_error(error)
-
     def get_container_client(self, container):
         # type: (Union[ContainerProperties, str]) -> ContainerClient
         """Get a client to interact with the specified container.
@@ -580,7 +497,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         )
         return ContainerClient(
             self.url, container_name=container_name,
-            credential=self.credential, api_version=self.api_version, _configuration=self._config,
+            credential=self.credential, _configuration=self._config,
             _pipeline=_pipeline, _location_mode=self._location_mode, _hosts=self._hosts,
             require_encryption=self.require_encryption, key_encryption_key=self.key_encryption_key,
             key_resolver_function=self.key_resolver_function, loop=self._loop)
@@ -635,7 +552,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         )
         return BlobClient( # type: ignore
             self.url, container_name=container_name, blob_name=blob_name, snapshot=snapshot,
-            credential=self.credential, api_version=self.api_version, _configuration=self._config,
+            credential=self.credential, _configuration=self._config,
             _pipeline=_pipeline, _location_mode=self._location_mode, _hosts=self._hosts,
             require_encryption=self.require_encryption, key_encryption_key=self.key_encryption_key,
             key_resolver_function=self.key_resolver_function, loop=self._loop)
