@@ -3,17 +3,16 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
+
 import logging
 from typing import (  # pylint: disable=unused-import
     TYPE_CHECKING
 )
-from xml.etree.ElementTree import Element
 
 from azure.core.pipeline.policies import ContentDecodePolicy
 from azure.core.exceptions import HttpResponseError, DecodeError, ResourceModifiedError, ClientAuthenticationError, \
     ResourceNotFoundError, ResourceExistsError
-from ._models import FileProperties, DirectoryProperties, LeaseProperties, DeletedPathProperties, StaticWebsite, \
-    RetentionPolicy, Metrics, AnalyticsLogging, PathProperties  # pylint: disable=protected-access
+from ._models import FileProperties, DirectoryProperties, LeaseProperties, PathProperties
 from ._shared.models import StorageErrorCode
 
 if TYPE_CHECKING:
@@ -49,34 +48,6 @@ def deserialize_path_properties(path_list):
     return [PathProperties._from_generated(path) for path in path_list] # pylint: disable=protected-access
 
 
-def get_deleted_path_properties_from_generated_code(generated):
-    deleted_path = DeletedPathProperties()
-    deleted_path.name = generated.name
-    deleted_path.deleted_time = generated.properties.deleted_time
-    deleted_path.remaining_retention_days = generated.properties.remaining_retention_days
-    deleted_path.deletion_id = generated.deletion_id
-    return deleted_path
-
-
-def is_file_path(_, __, headers):
-    if headers['x-ms-resource-type'] == "file":
-        return True
-    return False
-
-
-def get_datalake_service_properties(datalake_properties):
-    datalake_properties["analytics_logging"] = AnalyticsLogging._from_generated(    # pylint: disable=protected-access
-        datalake_properties["analytics_logging"])
-    datalake_properties["hour_metrics"] = Metrics._from_generated(datalake_properties["hour_metrics"])  # pylint: disable=protected-access
-    datalake_properties["minute_metrics"] = Metrics._from_generated(    # pylint: disable=protected-access
-        datalake_properties["minute_metrics"])
-    datalake_properties["delete_retention_policy"] = RetentionPolicy._from_generated(   # pylint: disable=protected-access
-        datalake_properties["delete_retention_policy"])
-    datalake_properties["static_website"] = StaticWebsite._from_generated(  # pylint: disable=protected-access
-        datalake_properties["static_website"])
-    return datalake_properties
-
-
 def from_blob_properties(blob_properties):
     file_props = FileProperties()
     file_props.name = blob_properties.name
@@ -93,7 +64,6 @@ def from_blob_properties(blob_properties):
     file_props.content_settings = blob_properties.content_settings
     return file_props
 
-
 def normalize_headers(headers):
     normalized = {}
     for key, value in headers.items():
@@ -111,46 +81,26 @@ def deserialize_metadata(response, obj, headers):  # pylint: disable=unused-argu
     return {k[10:]: v for k, v in raw_metadata.items()}
 
 
-def process_storage_error(storage_error):   # pylint:disable=too-many-statements
+def process_storage_error(storage_error):
     raise_error = HttpResponseError
-    serialized = False
-    if not storage_error.response:
-        raise storage_error
-    # If it is one of those three then it has been serialized prior by the generated layer.
-    if isinstance(storage_error, (ResourceNotFoundError, ClientAuthenticationError, ResourceExistsError)):
-        serialized = True
     error_code = storage_error.response.headers.get('x-ms-error-code')
     error_message = storage_error.message
     additional_data = {}
-    error_dict = {}
     try:
         error_body = ContentDecodePolicy.deserialize_from_http_generics(storage_error.response)
-        # If it is an XML response
-        if isinstance(error_body, Element):
-            error_dict = {
-                child.tag.lower(): child.text
-                for child in error_body
-            }
-        # If it is a JSON response
-        elif isinstance(error_body, dict):
-            error_dict = error_body.get('error', {})
-        elif not error_code:
-            _LOGGER.warning(
-                'Unexpected return type % from ContentDecodePolicy.deserialize_from_http_generics.', type(error_body))
-            error_dict = {'message': str(error_body)}
-
-        # If we extracted from a Json or XML response
-        if error_dict:
-            error_code = error_dict.get('code')
-            error_message = error_dict.get('message')
-            additional_data = {k: v for k, v in error_dict.items() if k not in {'code', 'message'}}
-
+        if error_body:
+            for info in error_body:
+                if info == 'code':
+                    error_code = error_body[info]
+                elif info == 'message':
+                    error_message = error_body[info]
+                else:
+                    additional_data[info] = error_body[info]
     except DecodeError:
         pass
 
     try:
-        # This check would be unnecessary if we have already serialized the error.
-        if error_code and not serialized:
+        if error_code:
             error_code = StorageErrorCode(error_code)
             if error_code in [StorageErrorCode.condition_not_met]:
                 raise_error = ResourceModifiedError
@@ -186,7 +136,6 @@ def process_storage_error(storage_error):   # pylint:disable=too-many-statements
         # Got an unknown error code
         pass
 
-    # Error message should include all the error properties
     try:
         error_message += "\nErrorCode:{}".format(error_code.value)
     except AttributeError:
@@ -194,19 +143,8 @@ def process_storage_error(storage_error):   # pylint:disable=too-many-statements
     for name, info in additional_data.items():
         error_message += "\n{}:{}".format(name, info)
 
-    # No need to create an instance if it has already been serialized by the generated layer
-    if serialized:
-        storage_error.message = error_message
-        error = storage_error
-    else:
-        error = raise_error(message=error_message, response=storage_error.response)
-    # Ensure these properties are stored in the error instance as well (not just the error message)
+    error = raise_error(message=error_message, response=storage_error.response,
+                        continuation_token=storage_error.continuation_token)
     error.error_code = error_code
     error.additional_info = additional_data
-    # error.args is what's surfaced on the traceback - show error message in all cases
-    error.args = (error.message,)
-    try:
-        # `from None` prevents us from double printing the exception (suppresses generated layer error context)
-        exec("raise error from None")   # pylint: disable=exec-used # nosec
-    except SyntaxError:
-        raise error
+    raise error
