@@ -9,7 +9,7 @@ from typing import (  # pylint: disable=unused-import
     Union, Optional, Any,
     TypeVar, TYPE_CHECKING
 )
-from azure.multiapi.storagev2.blob.v2020_06_12.aio import BlobLeaseClient
+from azure.multiapi.storagev2.blob.v2021_06_08.aio import BlobLeaseClient
 from .._data_lake_lease import DataLakeLeaseClient as DataLakeLeaseClientBase
 
 
@@ -19,7 +19,7 @@ if TYPE_CHECKING:
     DataLakeFileClient = TypeVar("DataLakeFileClient")
 
 
-class DataLakeLeaseClient(DataLakeLeaseClientBase):
+class DataLakeLeaseClient(DataLakeLeaseClientBase):  # pylint: disable=client-accepts-api-version-keyword
     """Creates a new DataLakeLeaseClient.
 
     This client provides lease operations on a FileSystemClient, DataLakeDirectoryClient or DataLakeFileClient.
