@@ -7,8 +7,6 @@
 from typing import (  # pylint: disable=unused-import
     Optional, Union, Dict, Any, Iterable, TYPE_CHECKING
 )
-
-
 try:
     from urllib.parse import urlparse, quote, unquote
 except ImportError:
@@ -16,7 +14,6 @@ except ImportError:
     from urllib2 import quote, unquote # type: ignore
 
 import six
-from azure.core.exceptions import HttpResponseError
 from azure.core.tracing.decorator import distributed_trace
 from azure.core.pipeline import Pipeline
 from ._shared.base_client import StorageAccountHostsMixin, TransportWrapper, parse_connection_str, parse_query
@@ -26,7 +23,9 @@ from ._shared.response_handlers import (
     process_storage_error,
     return_headers_and_deserialized)
 from ._generated import AzureFileStorage
+from ._generated.version import VERSION
 from ._generated.models import (
+    StorageErrorException,
     SignedIdentifier,
     DeleteSnapshotsOptionType,
     SharePermission)
@@ -35,8 +34,6 @@ from ._serialize import get_api_version, get_access_conditions
 from ._directory_client import ShareDirectoryClient
 from ._file_client import ShareFileClient
 from ._lease import ShareLeaseClient
-from ._models import ShareProtocols
-
 
 if TYPE_CHECKING:
     from ._models import ShareProperties, AccessPolicy
@@ -48,10 +45,6 @@ class ShareClient(StorageAccountHostsMixin):
     For operations relating to a specific directory or file in this share, the clients for
     those entities can also be retrieved using the :func:`get_directory_client` and :func:`get_file_client` functions.
 
-    For more optional configuration, please click
-    `here <https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/storage/azure-storage-file-share
-    #optional-configuration>`_.
-
     :param str account_url:
         The URI to the storage account. In order to create a client given the full URI to the share,
         use the :func:`from_share_url` classmethod.
@@ -63,8 +56,7 @@ class ShareClient(StorageAccountHostsMixin):
         or the response returned from :func:`create_snapshot`.
     :param credential:
         The credential with which to authenticate. This is optional if the
-        account URL already has a SAS token. The value can be a SAS token string,
-        an instance of a AzureSasCredential from azure.core.credentials or an account
+        account URL already has a SAS token. The value can be a SAS token string or an account
         shared access key.
     :keyword str api_version:
         The Storage API version to use for requests. Default value is '2019-07-07'.
@@ -114,8 +106,8 @@ class ShareClient(StorageAccountHostsMixin):
         self._query_str, credential = self._format_query_string(
             sas_token, credential, share_snapshot=self.snapshot)
         super(ShareClient, self).__init__(parsed_url, service='file-share', credential=credential, **kwargs)
-        self._client = AzureFileStorage(url=self.url, pipeline=self._pipeline)
-        self._client._config.version = get_api_version(kwargs) # pylint: disable=protected-access
+        self._client = AzureFileStorage(version=VERSION, url=self.url, pipeline=self._pipeline)
+        self._client._config.version = get_api_version(kwargs, VERSION)  # pylint: disable=protected-access
 
     @classmethod
     def from_share_url(cls, share_url,  # type: str
@@ -131,8 +123,7 @@ class ShareClient(StorageAccountHostsMixin):
             or the response returned from :func:`create_snapshot`.
         :param credential:
             The credential with which to authenticate. This is optional if the
-            account URL already has a SAS token. The value can be a SAS token string,
-            an instance of a AzureSasCredential from azure.core.credentials or an account
+            account URL already has a SAS token. The value can be a SAS token string or an account
             shared access key.
         :returns: A share client.
         :rtype: ~azure.storage.fileshare.ShareClient
@@ -204,8 +195,7 @@ class ShareClient(StorageAccountHostsMixin):
             or the response returned from :func:`create_snapshot`.
         :param credential:
             The credential with which to authenticate. This is optional if the
-            account URL already has a SAS token. The value can be a SAS token string,
-            an instance of a AzureSasCredential from azure.core.credentials or an account
+            account URL already has a SAS token. The value can be a SAS token string or an account
             shared access key.
         :returns: A share client.
         :rtype: ~azure.storage.fileshare.ShareClient
@@ -268,21 +258,21 @@ class ShareClient(StorageAccountHostsMixin):
             _pipeline=_pipeline, _location_mode=self._location_mode)
 
     @distributed_trace
-    def acquire_lease(self, **kwargs):
-        # type: (**Any) -> ShareLeaseClient
+    def acquire_lease(self, lease_duration=-1, lease_id=None, **kwargs):
+        # type: (int, Optional[str], **Any) -> ShareLeaseClient
         """Requests a new lease.
 
         If the share does not have an active lease, the Share
         Service creates a lease on the share and returns a new lease.
 
-        .. versionadded:: 12.5.0
+        .. versionadded:: 12.6.0
 
-        :keyword int lease_duration:
+        :param int lease_duration:
             Specifies the duration of the lease, in seconds, or negative one
             (-1) for a lease that never expires. A non-infinite lease can be
             between 15 and 60 seconds. A lease duration cannot be changed
             using renew or change. Default is -1 (infinite lease).
-        :keyword str lease_id:
+        :param str lease_id:
             Proposed lease ID, in a GUID string format. The Share Service
             returns 400 (Invalid request) if the proposed lease ID is not
             in the correct format.
@@ -300,8 +290,7 @@ class ShareClient(StorageAccountHostsMixin):
                 :dedent: 8
                 :caption: Acquiring a lease on a share.
         """
-        kwargs['lease_duration'] = kwargs.pop('lease_duration', -1)
-        lease_id = kwargs.pop('lease_id', None)
+        kwargs['lease_duration'] = lease_duration
         lease = ShareLeaseClient(self, lease_id=lease_id)  # type: ignore
         lease.acquire(**kwargs)
         return lease
@@ -316,22 +305,8 @@ class ShareClient(StorageAccountHostsMixin):
             Name-value pairs associated with the share as metadata.
         :keyword int quota:
             The quota to be allotted.
-        :keyword access_tier:
-            Specifies the access tier of the share.
-            Possible values: 'TransactionOptimized', 'Hot', 'Cool'
-        :paramtype access_tier: str or ~azure.storage.fileshare.models.ShareAccessTier
-
-            .. versionadded:: 12.4.0
-
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
-        :keyword protocols:
-            Protocols to enable on the share. Only one protocol can be enabled on the share.
-        :paramtype protocols: str or ~azure.storage.fileshare.ShareProtocols
-        :keyword root_squash:
-            Root squash to set on the share.
-            Only valid for NFS shares. Possible values include: 'NoRootSquash', 'RootSquash', 'AllSquash'.
-        :paramtype root_squash: str or ~azure.storage.fileshare.ShareRootSquash
         :returns: Share-updated property dict (Etag and last modified).
         :rtype: dict(str, Any)
 
@@ -346,14 +321,7 @@ class ShareClient(StorageAccountHostsMixin):
         """
         metadata = kwargs.pop('metadata', None)
         quota = kwargs.pop('quota', None)
-        access_tier = kwargs.pop('access_tier', None)
         timeout = kwargs.pop('timeout', None)
-        root_squash = kwargs.pop('root_squash', None)
-        protocols = kwargs.pop('protocols', None)
-        if protocols and protocols not in ['NFS', 'SMB', ShareProtocols.SMB, ShareProtocols.NFS]:
-            raise ValueError("The enabled protocol must be set to either SMB or NFS.")
-        if root_squash and protocols not in ['NFS', ShareProtocols.NFS]:
-            raise ValueError("The 'root_squash' keyword can only be used on NFS enabled shares.")
         headers = kwargs.pop('headers', {})
         headers.update(add_metadata_headers(metadata)) # type: ignore
 
@@ -362,13 +330,10 @@ class ShareClient(StorageAccountHostsMixin):
                 timeout=timeout,
                 metadata=metadata,
                 quota=quota,
-                access_tier=access_tier,
-                root_squash=root_squash,
-                enabled_protocols=protocols,
                 cls=return_response_headers,
                 headers=headers,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -413,7 +378,7 @@ class ShareClient(StorageAccountHostsMixin):
                 cls=return_response_headers,
                 headers=headers,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -431,8 +396,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
@@ -458,7 +423,7 @@ class ShareClient(StorageAccountHostsMixin):
                 lease_access_conditions=access_conditions,
                 delete_snapshots=delete_include,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -474,8 +439,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :returns: The share properties.
         :rtype: ~azure.storage.fileshare.ShareProperties
@@ -498,7 +463,7 @@ class ShareClient(StorageAccountHostsMixin):
                 cls=deserialize_share_properties,
                 lease_access_conditions=access_conditions,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
         props.name = self.share_name
         props.snapshot = self.snapshot
@@ -518,8 +483,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :returns: Share-updated property dict (Etag and last modified).
         :rtype: dict(str, Any)
@@ -536,68 +501,13 @@ class ShareClient(StorageAccountHostsMixin):
         access_conditions = get_access_conditions(kwargs.pop('lease', None))
         timeout = kwargs.pop('timeout', None)
         try:
-            return self._client.share.set_properties( # type: ignore
+            return self._client.share.set_quota( # type: ignore
                 timeout=timeout,
                 quota=quota,
-                access_tier=None,
                 lease_access_conditions=access_conditions,
                 cls=return_response_headers,
                 **kwargs)
-        except HttpResponseError as error:
-            process_storage_error(error)
-
-    @distributed_trace
-    def set_share_properties(self, **kwargs):
-        # type: (Any) ->  Dict[str, Any]
-        """Sets the share properties.
-
-        .. versionadded:: 12.4.0
-
-        :keyword access_tier:
-            Specifies the access tier of the share.
-            Possible values: 'TransactionOptimized', 'Hot', and 'Cool'
-        :paramtype access_tier: str or ~azure.storage.fileshare.models.ShareAccessTier
-        :keyword int quota:
-            Specifies the maximum size of the share, in gigabytes.
-            Must be greater than 0, and less than or equal to 5TB.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :keyword root_squash:
-            Root squash to set on the share.
-            Only valid for NFS shares. Possible values include: 'NoRootSquash', 'RootSquash', 'AllSquash'.
-        :paramtype root_squash: str or ~azure.storage.fileshare.ShareRootSquash
-        :keyword lease:
-            Required if the share has an active lease. Value can be a ShareLeaseClient object
-            or the lease ID as a string.
-        :returns: Share-updated property dict (Etag and last modified).
-        :rtype: dict(str, Any)
-
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/file_samples_share.py
-                :start-after: [START set_share_properties]
-                :end-before: [END set_share_properties]
-                :language: python
-                :dedent: 12
-                :caption: Sets the share properties.
-        """
-        access_conditions = get_access_conditions(kwargs.pop('lease', None))
-        timeout = kwargs.pop('timeout', None)
-        access_tier = kwargs.pop('access_tier', None)
-        quota = kwargs.pop('quota', None)
-        root_squash = kwargs.pop('root_squash', None)
-        if all(parameter is None for parameter in [access_tier, quota, root_squash]):
-            raise ValueError("set_share_properties should be called with at least one parameter.")
-        try:
-            return self._client.share.set_properties( # type: ignore
-                timeout=timeout,
-                quota=quota,
-                access_tier=access_tier,
-                root_squash=root_squash,
-                lease_access_conditions=access_conditions,
-                cls=return_response_headers,
-                **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -618,8 +528,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :returns: Share-updated property dict (Etag and last modified).
         :rtype: dict(str, Any)
@@ -644,7 +554,7 @@ class ShareClient(StorageAccountHostsMixin):
                 headers=headers,
                 lease_access_conditions=access_conditions,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -659,8 +569,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :returns: Access policy information in a dict.
         :rtype: dict[str, Any]
@@ -673,7 +583,7 @@ class ShareClient(StorageAccountHostsMixin):
                 cls=return_headers_and_deserialized,
                 lease_access_conditions=access_conditions,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
         return {
             'public_access': response.get('share_public_access'),
@@ -698,8 +608,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :returns: Share-updated property dict (Etag and last modified).
         :rtype: dict(str, Any)
@@ -724,7 +634,7 @@ class ShareClient(StorageAccountHostsMixin):
                 cls=return_response_headers,
                 lease_access_conditions=access_conditions,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -741,8 +651,8 @@ class ShareClient(StorageAccountHostsMixin):
             Required if the share has an active lease. Value can be a ShareLeaseClient object
             or the lease ID as a string.
 
-            .. versionadded:: 12.5.0
-            This keyword argument was introduced in API version '2020-08-04'.
+            .. versionadded:: 12.6.0
+            This keyword argument was introduced in API version '2020-02-02'.
 
         :return: The approximate size of the data (in bytes) stored on the share.
         :rtype: int
@@ -755,7 +665,7 @@ class ShareClient(StorageAccountHostsMixin):
                 lease_access_conditions=access_conditions,
                 **kwargs)
             return stats.share_usage_bytes # type: ignore
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -777,19 +687,6 @@ class ShareClient(StorageAccountHostsMixin):
             An opaque continuation token. This value can be retrieved from the
             next_marker field of a previous generator object. If specified,
             this generator will begin returning results from this point.
-        :keyword list[str] include:
-            Include this parameter to specify one or more datasets to include in the response.
-            Possible str values are "timestamps", "Etag", "Attributes", "PermissionKey".
-
-            .. versionadded:: 12.6.0
-            This keyword argument was introduced in API version '2020-10-02'.
-
-        :keyword bool include_extended_info:
-            If this is set to true, file id will be returned in listed results.
-
-            .. versionadded:: 12.6.0
-            This keyword argument was introduced in API version '2020-10-02'.
-
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :returns: An auto-paging iterable of dict-like DirectoryProperties and FileProperties
@@ -842,7 +739,7 @@ class ShareClient(StorageAccountHostsMixin):
         options = self._create_permission_for_share_options(file_permission, timeout=timeout, **kwargs)
         try:
             return self._client.share.create_permission(**options)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -869,7 +766,7 @@ class ShareClient(StorageAccountHostsMixin):
                 cls=deserialize_permission,
                 timeout=timeout,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
