@@ -5,7 +5,7 @@
 # --------------------------------------------------------------------------
 # pylint: disable=invalid-overridden-method
 from typing import (  # pylint: disable=unused-import
-    Optional, Any, IO, Iterable, AnyStr, Dict, List, Tuple,
+    Union, Optional, Any, IO, Iterable, AnyStr, Dict, List, Tuple,
     TypeVar, TYPE_CHECKING
 )
 
@@ -25,7 +25,7 @@ if TYPE_CHECKING:
 class ShareLeaseClient(LeaseClientBase):
     """Creates a new ShareLeaseClient.
 
-    This client provides lease operations on a ShareFileClient.
+    This client provides lease operations on a ShareClient or ShareFileClient.
 
     :ivar str id:
         The ID of the lease currently being maintained. This will be `None` if no
@@ -38,8 +38,9 @@ class ShareLeaseClient(LeaseClientBase):
         This will be `None` if no lease has yet been acquired or modified.
 
     :param client:
-        The client of the file to lease.
-    :type client: ~azure.storage.fileshare.ShareFileClient
+        The client of the file or share to lease.
+    :type client: ~azure.storage.fileshare.ShareFileClient or
+        ~azure.storage.fileshare.ShareClient
     :param str lease_id:
         A string representing the lease ID of an existing lease. This value does not
         need to be specified in order to acquire a new lease, or break one.
@@ -61,14 +62,20 @@ class ShareLeaseClient(LeaseClientBase):
     async def acquire(self, **kwargs):
         # type: (**Any) -> None
         """Requests a new lease. This operation establishes and manages a lock on a
-        file for write and delete operations. If the file does not have an active lease,
-        the File service creates a lease on the file. If the file has an active lease,
+        file or share for write and delete operations. If the file or share does not have an active lease,
+        the File or Share service creates a lease on the file or share. If the file has an active lease,
         you can only request a new lease using the active lease ID.
 
 
-        If the file does not have an active lease, the File service creates a
+        If the file or share does not have an active lease, the File or Share service creates a
         lease on the file and returns a new lease ID.
 
+        :keyword int lease_duration:
+            Specifies the duration of the lease, in seconds, or negative one
+            (-1) for a lease that never expires. File leases never expire. A non-infinite share lease can be
+            between 15 and 60 seconds. A share lease duration cannot be changed
+            using renew or change. Default is -1 (infinite share lease).
+
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :rtype: None
@@ -90,7 +97,7 @@ class ShareLeaseClient(LeaseClientBase):
         self.etag = response.get('etag')  # type: str
 
     @distributed_trace_async
-    async def _renew(self, **kwargs):
+    async def renew(self, **kwargs):
         # type: (Any) -> None
         """Renews the share lease.
 
@@ -125,8 +132,8 @@ class ShareLeaseClient(LeaseClientBase):
     async def release(self, **kwargs):
         # type: (Any) -> None
         """Releases the lease. The lease may be released if the lease ID specified on the request matches
-        that associated with the file. Releasing the lease allows another client to immediately acquire
-        the lease for the file as soon as the release is complete.
+        that associated with the share or file. Releasing the lease allows another client to immediately acquire
+        the lease for the share or file as soon as the release is complete.
 
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
@@ -153,7 +160,7 @@ class ShareLeaseClient(LeaseClientBase):
         a new lease ID in x-ms-proposed-lease-id.
 
         :param str proposed_lease_id:
-            Proposed lease ID, in a GUID string format. The File service raises an error
+            Proposed lease ID, in a GUID string format. The File or Share service raises an error
             (Invalid request) if the proposed lease ID is not in the correct format.
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
@@ -177,7 +184,7 @@ class ShareLeaseClient(LeaseClientBase):
     @distributed_trace_async
     async def break_lease(self, **kwargs):
         # type: (Any) -> int
-        """Force breaks the lease if the file has an active lease. Any authorized request can break the lease;
+        """Force breaks the lease if the file or share has an active lease. Any authorized request can break the lease;
         the request is not required to specify a matching lease ID. An infinite lease breaks immediately.
 
         Once a lease is broken, it cannot be changed. Any authorized request can break the lease;
@@ -185,6 +192,19 @@ class ShareLeaseClient(LeaseClientBase):
         When a lease is successfully broken, the response indicates the interval
         in seconds until a new lease can be acquired.
 
+        :keyword int lease_break_period:
+            This is the proposed duration of seconds that the share lease
+            should continue before it is broken, between 0 and 60 seconds. This
+            break period is only used if it is shorter than the time remaining
+            on the share lease. If longer, the time remaining on the share lease is used.
+            A new share lease will not be available before the break period has
+            expired, but the share lease may be held for longer than the break
+            period. If this header does not appear with a break
+            operation, a fixed-duration share lease breaks after the remaining share lease
+            period elapses, and an infinite share lease breaks immediately.
+
+            .. versionadded:: 12.5.0
+
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: Approximate time remaining in the lease period, in seconds.
